pub fn encode_i64(v: i64) -> u64Expand description
Encode a 64-bit value with ZigZag. ZigZag encodes signed integers into values that can be efficiently encoded with varint. (Otherwise, negative values must be sign-extended to 64 bits to be varint encoded, thus always taking 10 bytes on the wire.) see https://developers.google.com/protocol-buffers/docs/encoding#types